@@ -63,8 +63,8 @@ void MainWindow::get_roms()
     ui->listWidget->clear();
     QDir dir(rom_path);
     dir.setFilter(QDir::Files);
-    dir.setSorting(QDir::Name);
-    dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
+    dir.setSorting(QDir::Name | QDir::IgnoreCase);
+    dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img"<<"*.z"<<"*.znx");
 
     QFileInfoList list = dir.entryInfoList();
     int o=0;
@@ -76,6 +76,8 @@ void MainWindow::get_roms()
         QIcon icon(":/images/ICON0.PNG");
         if (QFile::exists(QString("%1.png").arg(fileInfo.filePath())))
             icon = QIcon(QString("%1.png").arg(fileInfo.filePath()));
+        else if (QFile::exists(QString("%1png").arg(fileInfo.filePath().replace(fileInfo.suffix(), ""))))
+            icon = QIcon(QString("%1png").arg(fileInfo.filePath().replace(fileInfo.suffix(), "")));
         ui->listWidget->addItem(new QListWidgetItem(icon, fileInfo.fileName()));
         roms.insert(o++,fileInfo.absoluteFilePath());
     }
