@@ -45,6 +45,7 @@ void options::hideEvent(QHideEvent *){
         connect (yes,SIGNAL(clicked()),dlg,SLOT(accept()));
         connect (no,SIGNAL(clicked()),dlg,SLOT(reject()));
         connect (dlg,SIGNAL(accepted()),this,SLOT(save_cfg()));
+        connect (dlg,SIGNAL(rejected()),this,SLOT(reload_cfg()));
         lay->addWidget(yes,2,0);
         lay->addWidget(no ,2,1);
         dlg->exec();
@@ -246,6 +247,11 @@ void options::createCfg(){
 }
 }
 
+void options::reload_cfg()
+{
+    load_cfg();
+}
+
 void options::save_cfg(){
     createCfg();
     QString path="";
@@ -308,6 +314,10 @@ void options::save_cfg(){
 ;
 
     QFile file(path);
+    QFileInfo pathInfo(path);
+    if (!QDir().exists(pathInfo.path()))
+        QDir().mkpath(pathInfo.path());
+
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)){
         qDebug(QString("Can't save %1").arg(path).toAscii());
         return;}
